@@ -7,6 +7,7 @@
     if (missing(data)) {
         data <- parent.frame()
     }
+    formula <- formula(terms(formula, data=data))
     X <- formula[[2]]
     X <- eval(X)
     if (!inherits(X, "dist")) {
@@ -17,7 +18,7 @@
     inertia <- paste(toupper(substr(inertia, 1, 1)), substr(inertia, 
                                                             2, 256), sep = "")
     inertia <- paste("squared", inertia, "distance")
-    if (add)
+    if (add) 
         inertia <- paste(inertia, "(euclidified)")
     k <- attr(X, "Size") - 1
     if (max(X) >= 4 + .Machine$double.eps) {
@@ -29,8 +30,8 @@
     }
     nm <- attr(X, "Labels")
     X <- cmdscale(X, k = k, eig = TRUE, add = add)
-    if (is.null(rownames(X$points)))
-        rownames(X$points) <- nm 
+    if (is.null(rownames(X$points))) 
+        rownames(X$points) <- nm
     X$points <- adjust * X$points
     neig <- min(which(X$eig < 0) - 1, k)
     sol <- X$points[, 1:neig]
@@ -39,13 +40,12 @@
     sol <- rda.default(d$X, d$Y, d$Z, ...)
     sol$tot.chi <- sol$tot.chi
     if (!is.null(sol$CCA)) {
-        colnames(sol$CCA$u) <- colnames(sol$CCA$biplot) <-
-            names(sol$CCA$eig) <- colnames(sol$CCA$wa) <-
-                colnames(sol$CCA$v) <- paste("CAP", 1:ncol(sol$CCA$u), sep = "")
+        colnames(sol$CCA$u) <- colnames(sol$CCA$biplot) <- names(sol$CCA$eig) <- colnames(sol$CCA$wa) <- colnames(sol$CCA$v) <- paste("CAP", 
+                                                                                                                                      1:ncol(sol$CCA$u), sep = "")
     }
     if (!is.null(sol$CA)) {
-        colnames(sol$CA$u) <- names(sol$CA$eig) <- colnames(sol$CA$v) <-
-            paste("MDS", 1:ncol(sol$CA$u), sep="")
+        colnames(sol$CA$u) <- names(sol$CA$eig) <- colnames(sol$CA$v) <- paste("MDS", 
+                                                                               1:ncol(sol$CA$u), sep = "")
     }
     if (!is.null(comm)) {
         comm <- scale(comm, center = TRUE, scale = FALSE)
