@@ -2,15 +2,17 @@
     function (x, ...) 
 {
     x <- as.rad(x)
+    NU <- rad.null(x, ...)
     PE <- rad.preempt(x, ...)
+    #BS <- rad.brokenstick(x, ...)
     LN <- rad.lognormal(x, ...)
-    VL <- rad.veil(x, ...)
     ZP <- rad.zipf(x, ...)
     ZM <- rad.zipfbrot(x, ...)
     out <- list(y = x, family = PE$family)
-    models <- list(Preemption = PE, Lognormal = LN, Veiled.LN = VL, 
+    models <- list(Null = NU, Preemption = PE, Lognormal = LN,
                    Zipf = ZP, Mandelbrot = ZM)
     out$models <- models
     class(out) <- "radfit"
     out
 }
+
