@@ -2,11 +2,12 @@
     function (x, method = "bray", binary = FALSE, diag = FALSE, upper = FALSE, 
               na.rm = FALSE, ...) 
 {
+    ZAP <- 1e-15
     if (!is.na(pmatch(method, "euclidian"))) 
         method <- "euclidean"
     METHODS <- c("manhattan", "euclidean", "canberra", "bray", 
                  "kulczynski", "gower", "morisita", "horn", "mountford", 
-                 "jaccard", "raup", "binomial")
+                 "jaccard", "raup", "binomial", "chao")
     method <- pmatch(method, METHODS)
     if (is.na(method)) 
         stop("invalid distance method")
@@ -17,20 +18,21 @@
     if (method > 2 && any(x < 0, na.rm = TRUE)) 
         warning("results may be meaningless because input data have negative entries\n")
     if (method == 11 && any(colSums(x) == 0)) 
-        warning("Data includes empty species which influence the results")
+        warning("data includes empty species which influence the results")
     if (method == 6) 
         x <- decostand(x, "range", 2, na.rm = TRUE, ...)
     if (binary) 
         x <- decostand(x, "pa")
     N <- nrow(x <- as.matrix(x))
-    if (method == 7 && !identical(all.equal(as.integer(x), as.vector(x)), 
+    if (method %in% c(7, 13) && !identical(all.equal(as.integer(x), as.vector(x)), 
         TRUE)) 
-        warning("Morisita index may give meaningless results with non-integer values\n")
+        warning("index may give meaningless results with non-integer values\n")
     d <- .C("veg_distance", x = as.double(x), nr = N, nc = ncol(x), 
             d = double(N * (N - 1)/2), diag = as.integer(FALSE), 
             method = as.integer(method), NAOK = na.rm, PACKAGE = "vegan")$d
     if (method == 10) 
         d <- 2 * d/(1 + d)
+    d[d < ZAP] <- 0
     if (any(is.na(d))) 
         warning("missing values in results")
     attr(d, "Size") <- N
